use axum::{extract::Multipart, http::StatusCode};
use log::error;

use crate::utilities::{
    app_error::AppError, liquid_rescale::liquid_rescale_image, parse_image::parse_image,
};

pub async fn liquid_rescale_processor(multipart: Multipart) -> Result<Vec<u8>, AppError> {
    let image = parse_image(multipart).await.map_err(|err| {
        error!("Error in the multipart data parsing: {:?}", err);
        AppError::new(StatusCode::INTERNAL_SERVER_ERROR, "Missing file field")
    })?;

    let image_data = liquid_rescale_image(&image).map_err(|err| {
        error!("Imagemagick error: {:?}", err);
        AppError::new(
            StatusCode::INTERNAL_SERVER_ERROR,
            "There was a error read your image",
        )
    })?;

    Ok(image_data)
}
